@@ -149,6 +149,15 @@
     (pp99 tree)
     ))
 
+(when #f
+  (let* ((code
+	  (string-append
+	   "#define bar(X) #X\n"
+	   "#define foo(X) bar(X)\n"
+	   "char *s = foo('abc');\n"))
+	 (tree (parse-string code #:mode 'decl)))
+    (pp tree)))
+
 (when #f
   (let* ((code
 	  (string-append
