@@ -1,6 +1,6 @@
 ;;; nyacc/parse.scm
 
-;; Copyright (C) 2014-2018 Matthew R. Wette
+;; Copyright (C) 2014-2020 Matthew R. Wette
 ;;
 ;; This library is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public
@@ -30,6 +30,12 @@
 (define $default 1)			; sync w/ lalr.scm
 (define $error 2)			; sync w/ lalr.scm
 
+(use-modules (ice-9 pretty-print))
+(define (pperr exp)
+  (pretty-print exp (current-error-port) #:per-line-prefix "  "))
+(define (sferr fmt . args)
+  (apply simple-format (current-error-port) fmt args))
+
 (define (vector-map proc vec)		; see (srfi srfi-43)
   (let* ((ln (vector-length vec)) (res (make-vector ln)))
     (let loop ((ix 0))
@@ -51,9 +57,6 @@
 		    (eval f (or env (current-module))))
 		  (vector-map (lambda (ix actn) (wrap-action actn)) av))))
 
-(define (sferr fmt . args)
-  (apply simple-format (current-error-port) fmt args))
-
 (define (dmsg/n s t a ntab)
   (let ((t (or (assq-ref ntab t) t)))
     (cond
@@ -234,6 +237,9 @@
           '(interaction-environment)').  The default is to use
           '(current-module)'; that is, the module in which this
           procedure is being executed."
+
+  ;; BUG: this should fail if rrconf exists.
+
   (let* ((mtab (assq-ref mach 'mtab))
 	 (siu (map (lambda (n) (assoc-ref mtab n)) skip-if-unexp))
 	 (iact interactive))
